Name:		cantata
Version:	2.0.1
Release:	%mkrel 5
Summary:	Graphical client for the Music Player Daemon (MPD)
License:	GPLv2+
Group:		Graphical desktop/KDE
URL:		https://github.com/CDrummond/cantata/
Source0:	https://github.com/CDrummond/cantata/releases/download/v%{version}/%{name}-%{version}.tar.bz2
Patch0:		cantata-1.3.4-libsolid_static.patch

BuildRequires:	cmake
BuildRequires:	cdparanoia
BuildRequires:	cdda-devel
BuildRequires:	ffmpeg-devel
BuildRequires:	qtmultimedia5
BuildRequires:	qttools5
BuildRequires:	pkgconfig(Qt5Concurrent)
BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5DBus)
BuildRequires:	pkgconfig(Qt5Gui)
BuildRequires:	pkgconfig(Qt5Multimedia)
BuildRequires:	pkgconfig(Qt5Network)
BuildRequires:	pkgconfig(Qt5Sql)
BuildRequires:	pkgconfig(Qt5Svg)
BuildRequires:	pkgconfig(Qt5Widgets)
BuildRequires:	pkgconfig(Qt5Xml)
BuildRequires:	pkgconfig(libcddb)
BuildRequires:	pkgconfig(libmpg123)
BuildRequires:	pkgconfig(libmtp)
BuildRequires:	pkgconfig(libmusicbrainz5)
BuildRequires:	pkgconfig(libvlc)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(phonon4qt5)
BuildRequires:	pkgconfig(speexdsp)
BuildRequires:	pkgconfig(taglib) >= 1.6
BuildRequires:	pkgconfig(taglib-extras)
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(zlib)

Recommends:	mpd

%description
Cantata is a (yet another!) graphical client for the music player daemon (MPD).

Supporting features:
  * Multiple MPD collections.
  * Highly customisable layout.
  * Songs grouped by album in play queue.
  * Context view to show artist, album, and song information of current track.
  * Simple tag editor.
  * File organizer - use tags to organize files and folders.
  * Ability to calculate ReplyGain tags.
  * Dynamic playlists.
  * Online services; Jamendo, Magnatune, SoundCloud, and Podcasts.
  * Radio stream support - with the ability to search for streams via TuneIn,
    ShoutCast, or Dirble.
  * USB-Mass-Storage and MTP device support.
  * Audio CD ripping and playback.
  * Playback of non-MPD songs, via simple in-built HTTP server if connected
    to MPD via a standard socket, otherwise filepath is sent to MPD.
  * MPRISv2 DBUS interface.
  * Support for KDE global shortcuts (KDE builds), GNOME media keys, and
    standard media keys (via Qxt support).
  * Ubuntu/ambiance theme integration.
  * Basic support for touch-style interface (views are made 'flickable').
  * Scrobbling.
  * Ratings support.

%files
%doc AUTHORS ChangeLog LICENSE README TODO
%{_sysconfdir}/dbus-1/system.d/mpd.cantata.mounter.conf
%{_bindir}/%{name}
%{_libdir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/%{name}/
%{_datadir}/dbus-1/system-services/mpd.cantata.mounter.service
%{_iconsdir}/hicolor/*/apps/%{name}.*

#------------------------------------------------------------------------------

%prep
%setup -q
%autopatch -p1

# Hack to fix install path for x86_64 build
# TODO report upstream for a fix -done.
sed -i -e 's|LINUX_LIB_DIR lib|LINUX_LIB_DIR %{_lib}|g' CMakeLists.txt
sed -i -e 's|lib/cantata|%{_lib}/cantata|g' devices/mounter/CMakeLists.txt
sed -i -e 's|lib/cantata|%{_lib}/cantata|g' devices/mounter/mpd.cantata.mounter.service.cmake

%build
%cmake_qt5 \
	-DENABLE_QT5=ON \
	-DENABLE_HTTP_STREAM_PLAYBACK=ON \
	-DENABLE_REMOTE_DEVICES=ON 
%make_build

%install
%make_install -C build


%changelog
* Tue May 02 2017 akien <akien> 2.0.1-5.mga6
+ Revision: 1098271
- Rebuild for ffmpeg 3.3

* Wed Mar 08 2017 akien <akien> 2.0.1-4.mga6
+ Revision: 1089844
- Rebuild for ffmpeg 3.2.4

* Thu Jun 23 2016 daviddavid <daviddavid> 2.0.1-3.mga6
+ Revision: 1037354
- but recommends mpd instead

* Wed Jun 22 2016 daviddavid <daviddavid> 2.0.1-2.mga6
+ Revision: 1037174
- do not requires mpd (fixes mga#16678)

* Fri Jun 03 2016 daviddavid <daviddavid> 2.0.1-1.mga6
+ Revision: 1020183
- new version: 2.0.1
- remove merged upstream patch

* Tue Mar 15 2016 daviddavid <daviddavid> 2.0.0-2.mga6
+ Revision: 990890
- compile code with -fPIC (fix build)
  * add patch to fix cmake CXXFLAGS
  * add -DCMAKE_CXX_FLAGS='-fPIC' cmake option
- improve more description

* Tue Jan 26 2016 daviddavid <daviddavid> 2.0.0-1.mga6
+ Revision: 927841
- new version: 2.0.0
- switch build to Qt5
- update URL and Source URL
- improve description and summary

* Sat Oct 24 2015 daviddavid <daviddavid> 1.4.1-10.mga6
+ Revision: 894882
- remove empty lang files to fix build with latest rpm

* Tue Sep 01 2015 cjw <cjw> 1.4.1-9.mga6
+ Revision: 871908
- rebuild with gcc 5

* Thu Jul 02 2015 fwang <fwang> 1.4.1-8.mga6
+ Revision: 849448
- rebuild for libmusicbrainz5

* Fri Nov 14 2014 akien <akien> 1.4.1-7.mga5
+ Revision: 797172
- Rebuild for ffmpeg 2.4

* Wed Oct 15 2014 umeabot <umeabot> 1.4.1-6.mga5
+ Revision: 741291
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.4.1-5.mga5
+ Revision: 726011
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.4.1-4.mga5
+ Revision: 678306
- Mageia 5 Mass Rebuild

* Wed Sep 10 2014 fwang <fwang> 1.4.1-3.mga5
+ Revision: 674512
- build solid as static

* Wed Sep 10 2014 fwang <fwang> 1.4.1-2.mga5
+ Revision: 674492
- rebuild

* Sun Aug 31 2014 bersuit <bersuit> 1.4.1-1.mga5
+ Revision: 670078
- Update to new Upstream version 1.4.1
- Update to new Upstream version 1.3.4

* Sat Apr 05 2014 juancho <juancho> 1.3.3-1.mga5
+ Revision: 611789
- Updated to 1.3.3

* Sat Oct 19 2013 umeabot <umeabot> 1.1.2-2.mga4
+ Revision: 533656
- Mageia 4 Mass Rebuild

* Tue Sep 03 2013 fwang <fwang> 1.1.2-1.mga4
+ Revision: 474642
- update installdir for replaygain
- update file list
- new version 1.1.2

* Fri Jul 12 2013 fwang <fwang> 1.0.3-2.mga4
+ Revision: 453256
- fix build with recent ffmpeg
- rebuild for new ffmpeg

* Thu May 30 2013 fwang <fwang> 1.0.3-1.mga4
+ Revision: 433335
- fix desktop file
- update file list
- new version 1.0.3

* Thu Feb 07 2013 juancho <juancho> 0.9.2-1.mga3
+ Revision: 395053
- Updated to 0.9.2 (bugfix release)

* Fri Jan 11 2013 umeabot <umeabot> 0.9.1-3.mga3
+ Revision: 347387
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jan 08 2013 fwang <fwang> 0.9.1-2.mga3
+ Revision: 341614
- rebuild for new ffmpeg

* Sat Dec 22 2012 fwang <fwang> 0.9.1-1.mga3
+ Revision: 333798
- new version 0.9.1

* Sat Dec 08 2012 fwang <fwang> 0.9.0-1.mga3
+ Revision: 328018
- update file list
- new version 0.9.0

* Thu Sep 06 2012 fwang <fwang> 0.8.3-1.mga3
+ Revision: 288733
- new version 0.8.3

* Thu Jul 26 2012 fwang <fwang> 0.8.2-1.mga3
+ Revision: 274441
- new version 0.8.2

* Tue Jul 17 2012 fwang <fwang> 0.8.1-2.mga3
+ Revision: 271647
- add more features

* Tue Jul 17 2012 fwang <fwang> 0.8.1-1.mga3
+ Revision: 271642
- new version 0.8.1

* Tue Jun 05 2012 juancho <juancho> 0.7.1-1.mga3
+ Revision: 255949
- Added missing BR taglib-devel
- Updated to 0.7.1

* Thu Feb 02 2012 juancho <juancho> 0.3.0-1.mga2
+ Revision: 204003
- Updated to 0.3.0

* Mon Jan 09 2012 juancho <juancho> 0.2.0-2.mga2
+ Revision: 194223
- Removed now uneeded cmake option

* Mon Jan 09 2012 juancho <juancho> 0.2.0-1.mga2
+ Revision: 193698
- Updated to 0.2.0 - Upload sources
- Updated to 0.2.0

* Fri Jan 06 2012 juancho <juancho> 0.1.2-1.mga2
+ Revision: 192746
- imported package cantata

